PercutaneousProcedure constant
IriTerm
const PercutaneousProcedure
IRI for schemaHttp:PercutaneousProcedure
A type of medical procedure that involves percutaneous techniques, where access to organs or tissue is achieved via needle-puncture of the skin. For example, catheter-based procedures like stent delivery.
Implementation
static const PercutaneousProcedure = IriTerm(
'http://schema.org/PercutaneousProcedure',
);