QAPage constant
IriTerm
const QAPage
IRI for schemaHttp:QAPage
A QAPage is a WebPage focussed on a specific Question and its Answer(s), e.g. in a question answering site or documenting Frequently Asked Questions (FAQs).
Implementation
static const QAPage = IriTerm('http://schema.org/QAPage');