RecommendedDoseSchedule constant
IriTerm
const RecommendedDoseSchedule
IRI for schemaHttp:RecommendedDoseSchedule
A recommended dosing schedule for a drug or supplement as prescribed or recommended by an authority or by the drug/supplement's manufacturer. Capture the recommending authority in the recognizingAuthority property of MedicalEntity.
Implementation
static const RecommendedDoseSchedule = IriTerm(
'http://schema.org/RecommendedDoseSchedule',
);