accessMode constant

IriTerm const accessMode

accessMode [Expects: http://schema.org/Text]

The human sensory perceptual system or cognitive faculty through which a person may process or perceive the intellectual content of a resource, not including any adaptations of the content (e.g., text alternatives for images). Values should be drawn from the approved vocabulary.

Can be used on: http://schema.org/CreativeWork

Implementation

static const accessMode = IriTerm('http://schema.org/accessMode');